@@ -1,5 +1,5 @@
 ; Prototype to insert Lilypond Standalone Directives. Wants a pair with car Tag and cdr lilypond: (cons "BreathMark" "\\breathe")
-(define* (StandAloneDirectiveProto pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f) (data #f))
+(define* (StandAloneDirectiveProto pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f) (data #f) (overrides #f))
     (d-Directive-standalone (car pair))
     (d-DirectivePut-standalone-postfix (car pair) (cdr pair))
     (d-DirectivePut-standalone-minpixels (car pair) 30)
@@ -13,6 +13,8 @@
           (d-DirectivePut-standalone-display (car pair) (cdr pair)))
     (if minpixels
       (d-DirectivePut-standalone-minpixels (car pair) minpixels))
+    (if overrides
+      (d-DirectivePut-standalone-override (car pair) overrides))
     (if step?
         (d-MoveCursorRight))
     (d-RefreshDisplay))
@@ -40,10 +42,10 @@
             ((#f)  (d-InfoDialog (_ "Cancelled")))))
             
 ; Procedure to insert Self-Editing Lilypond Standalone Directives. Takes a pair with car Tag and cdr lilypond: (cons "BreathMark" "\\breathe") with optional boolean to step right after insertion and graphic
-(define* (StandAloneSelfEditDirective pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f))
+(define* (StandAloneSelfEditDirective pair #:optional (step? #t) (graphic #f) (displaytext #f) (minpixels #f) (overrides #f))
     (if (d-Directive-standalone? (car pair))
       (EditStandaloneDirective (car pair) displaytext)
-      (StandAloneDirectiveProto pair step? graphic displaytext minpixels)))
+      (StandAloneDirectiveProto pair step? graphic displaytext minpixels overrides)))
 
 ;Wrapper to attach any lilypond directive anywhere.
 ;;Wants four strings and an arbitrary number of tags (numbers) for overrides.
