@@ -1,8 +1,10 @@
 ;ScoreRehearsalMarkFormat
 (let ((tag "ScoreRehearsalMarkFormat")
-        (choice (RadioBoxMenu (cons (_ "alphabetic") "#format-mark-alphabet")
+        (choice (RadioBoxMenu
+                (cons (_ "Default") "#format-mark-letters")
+                (cons (_ "Alphabetic") "#format-mark-alphabet")
                 (cons (_ "Numeric") "#format-mark-numbers")
-                (cons (_ "Boxed alphabetic") "")
+                (cons (_ "Boxed alphabetic") "#format-mark-box-alphabet")
                 (cons (_ "Boxed numeric") "#format-mark-box-numbers")
                 (cons (_ "Circled alphabetic") "#format-mark-circle-alphabet")
                 (cons (_ "Circled numeric") "#format-mark-circle-numbers"))))
