@@ -70,6 +70,19 @@ typedef enum DenemoGraphicType
     DENEMO_PATTERN,
     DENEMO_FONT
   } DenemoGraphicType;
+typedef enum DenemoActionType
+  {
+    DENEMO_SCHEME = 0,
+    DENEMO_MENU_ITEM
+  } DenemoActionType;
+    
+typedef struct DenemoAction {
+    gchar *name;
+    gchar *label;
+    gchar *tooltip;
+    DenemoActionType type;
+    gpointer callback;
+} DenemoAction; 
 
 typedef struct DenemoGlyph
 {
@@ -105,6 +118,7 @@ typedef struct DenemoPalette
     gchar *name;
     GtkWidget *box;
     GtkWidget *window;
+    gboolean menu;/* if this widget is derived from a menu */
     gboolean rows; /* widgets should be packed row-wise or not */
     gint limit; /* how many widgets to pack in the chosen direction */
     gboolean docked; /**< whether this palette is displayed in the main display */
@@ -172,10 +186,10 @@ typedef enum tuplet_type{
  * Enumeration for Denemo's input mode
  */
 typedef enum input_mode {
-#define MODE_MASK (~(INPUTCLASSIC|INPUTEDIT|INPUTINSERT))
-  INPUTCLASSIC = 1<<0, /* classic mode */
-  INPUTEDIT = 1<<1, /* edit mode */
-  INPUTINSERT = 1<<2, /* insert mode */
+#define MODE_MASK (~(INPUTEDIT))
+        /*INPUTCLASSIC = 1<<0,  classic mode */
+  INPUTEDIT = 1<<1,/*edit mode, the only mode, as we are now non-modal  */
+        /* INPUTINSERT = 1<<2, insert mode*/
 #define ENTRY_TYPE_MASK (~(INPUTNORMAL|INPUTREST|INPUTBLANK))
   INPUTNORMAL = 1<<3, /* entry type notes */
   INPUTREST = 1<<4, /* entry type rests */
@@ -582,7 +596,8 @@ typedef struct DenemoDirective
 #define DENEMO_OVERRIDE_AFFIX (1<<4)
 #define DENEMO_OVERRIDE_TAGEDIT (1<<5)
 
-
+//for with{} blocks in staff directives
+#define DENEMO_OVERRIDE_WITH (DENEMO_ALT_OVERRIDE | DENEMO_OVERRIDE_AFFIX) 
 
 #define DENEMO_OVERRIDE_VOLUME (1<<8)
 #define DENEMO_OVERRIDE_DURATION (1<<9)
@@ -673,9 +688,9 @@ typedef enum
 
 
 typedef enum InputSource {
-  INPUTKEYBOARD,
-  INPUTAUDIO,
-  INPUTMIDI
+  INPUTKEYBOARD = 0,
+  INPUTAUDIO = 2,
+  INPUTMIDI = 1
 } InputSource;
 
 typedef enum MidiDestination {
@@ -920,7 +935,6 @@ typedef struct DenemoMovement
   DenemoRecording *recording;/**< Audio or MIDI recording attached to movement */
   gint marked_onset_position;/**< horizontal position in display of note onset in audio marked by user */
   GList *marked_onset;/**< Note onset in audio selected by user */
-  GList *sources; /**< List of source pixbufs, one for each measure score-view*/
   gdouble start_time; /**< time in seconds to start playing at */
   gdouble end_time; /**< time to end playing at */
   DenemoObject *playingnow; /**< the last object played via MIDI; it must not be dereferenced as it may no longer exist */
