@@ -393,9 +393,9 @@ action_note_into_score (gint mid_c_offset, gint enshift, gint octave)
   gui->last_source = INPUTMIDI;
   gui->movement->cursor_y = gui->movement->staffletter_y = mid_c_offset;
   gui->movement->cursor_y += 7 * octave;
-  //shiftcursor (gui, mid_c_offset);
-  //setenshift (gui->movement, enshift);
-  edit_pitch (mid_c_offset, enshift);
+  Denemo.project->movement->pending_enshift = enshift;
+  edit_or_append_pitch (mid_c_offset, TRUE);
+  Denemo.project->movement->pending_enshift = 0;
   displayhelper (gui);
 }
 
@@ -426,9 +426,9 @@ void new_midi_recording (void) {
     {
       //FIXME a better name for the mutex which originally was just for midi data, but will work for audio data too.
       recording = Denemo.project->movement->recording;
-      g_static_mutex_lock (&smfmutex);
+      g_mutex_lock (&smfmutex);
       Denemo.project->movement->recording = NULL;
-      g_static_mutex_unlock (&smfmutex);
+      g_mutex_unlock (&smfmutex);
       g_free (recording->filename);
       g_free (recording);
       g_list_free_full (recording->notes, g_free);
