@@ -22,11 +22,11 @@ void start_pitch_input (void);
 gboolean pitch_recognition_system_active (void);
 gboolean delete_tone (DenemoMovement * si, chord * thechord);
 gboolean apply_tones (DenemoMovement * si);
-void clear_overlay (GtkAction * action, DenemoScriptParam* param);
+void clear_overlay (DenemoAction * action, DenemoScriptParam* param);
 void store_pitch (double pitch);
 double get_pitch (void);
-void set_sharper (GtkAction * action, DenemoScriptParam * param);
-void set_flatter (GtkAction * action, DenemoScriptParam * param);
+void set_sharper (DenemoAction * action, DenemoScriptParam * param);
+void set_flatter (DenemoAction * action, DenemoScriptParam * param);
 gchar *determine_interval (gint bass, gint harmony, gboolean * status);
 gchar *sharpest (void);
 gchar *flattest (void);
