@@ -201,10 +201,9 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
               g_free (name);
             }
           if (Denemo.ScriptRecording)
-                        if (idx_has_callback (the_keymap, command_idx))
-                            {
-                                append_scheme_call ((gchar *) command_name);
-                            }
+            {
+                append_scheme_call ((gchar *) command_name);
+            }
           //g_debug("Single Key shortcut %s invokes %s\n", dnm_accelerator_name(event->keyval, event->state), command_name);
           return perform_command (command_name, event);
         }
@@ -234,11 +233,10 @@ process_key_event (GdkEventKey * event, gchar * perform_command ())
                 {
                   KeyStrokeShow (prefix_store->str, command_idx, FALSE);
                 }
-                    if (Denemo.ScriptRecording)
-                            if (idx_has_callback (the_keymap, command_idx))
-                                {
-                                    append_scheme_call ((gchar *) command_name);
-                                }
+              if (Denemo.ScriptRecording)
+                {
+                append_scheme_call ((gchar *) command_name);
+                }
               ret = perform_command (command_name, event);
             }
         }
@@ -335,7 +333,7 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
  * Reduce the measure width by 10 pixels
  */
 void
-adjust_measure_less_width_key (GtkAction* action, DenemoScriptParam *param)
+adjust_measure_less_width_key (DenemoAction* action, DenemoScriptParam *param)
 {
   adjustmeasurewidth (Denemo.project->movement, -10);
 }
@@ -344,7 +342,7 @@ adjust_measure_less_width_key (GtkAction* action, DenemoScriptParam *param)
  * Enlarge the measure width by 10 pixels
  */
 void
-adjust_measure_more_width_key (GtkAction* action, DenemoScriptParam *param)
+adjust_measure_more_width_key (DenemoAction* action, DenemoScriptParam *param)
 {
   adjustmeasurewidth (Denemo.project->movement, 10);
 }
@@ -353,7 +351,7 @@ adjust_measure_more_width_key (GtkAction* action, DenemoScriptParam *param)
  * Reduce the staff height by 10 pixels
  */
 void
-adjust_staff_less_height_key (GtkAction* action, DenemoScriptParam *param)
+adjust_staff_less_height_key (DenemoAction* action, DenemoScriptParam *param)
 {
   adjuststaffheight (Denemo.project->movement, -10);
 }
@@ -362,7 +360,7 @@ adjust_staff_less_height_key (GtkAction* action, DenemoScriptParam *param)
  * Enlarge the staff height by 10 pixels
  */
 void
-adjust_staff_more_height_key (GtkAction* action, DenemoScriptParam *param)
+adjust_staff_more_height_key (DenemoAction* action, DenemoScriptParam *param)
 {
   adjuststaffheight (Denemo.project->movement, 10);
 
@@ -377,20 +375,29 @@ unset_selection_key (DenemoScriptParam *param)
   Denemo.project->movement->markstaffnum = 0;
 }
 
-/**
- * Insert quarter note into score
- */
-void
-insert_chord_key (DenemoScriptParam *param)
+
+static void move_to_note_by_command (gchar note)
 {
-  dnm_insertnote (Denemo.project, 2, Denemo.project->mode, FALSE);
+    
+  Denemo.project->last_source = INPUTKEYBOARD;
+  move_to_pitch (Denemo.project, ((note + 5 - 'A') % 7));  
 }
 
-void
-go_to_key(gchar note, DenemoScriptParam *param)
+static void
+insert_note_by_command(gchar note)
 {
   Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, ((note + 5 - 'A') % 7));
+  insert_pitch (Denemo.project, ((note + 5 - 'A') % 7));
+}
+
+
+static void change_or_append_x_key (gint key)
+{
+  //move_to_pitch (Denemo.project, key);
+  //gint enshift = get_cursoracc();g_print ("Cursoracc for change_or_append_x_key is %d\n", enshift);
+  Denemo.project->last_source = INPUTKEYBOARD;
+  edit_or_append_pitch (key, FALSE); 
+    
 }
 
 /**
@@ -398,10 +405,9 @@ go_to_key(gchar note, DenemoScriptParam *param)
  *
  */
 void
-go_to_A_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_A_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 5);
+  change_or_append_x_key (5);
 }
 
 /**
@@ -409,10 +415,9 @@ go_to_A_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_B_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_B_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 6);
+  change_or_append_x_key (6);
 }
 
 /**
@@ -420,10 +425,9 @@ go_to_B_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_C_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_C_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 0);
+  change_or_append_x_key (0);
 }
 
 /**
@@ -431,9 +435,9 @@ go_to_C_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_D_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_D_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  shiftcursor (Denemo.project, 1);
+  change_or_append_x_key (1);
 }
 
 /**
@@ -441,10 +445,9 @@ go_to_D_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_E_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_E_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 2);
+  change_or_append_x_key (2);
 }
 
 /**
@@ -452,10 +455,9 @@ go_to_E_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_F_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_F_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 3);
+  change_or_append_x_key (3);
 }
 
 /**
@@ -463,10 +465,9 @@ go_to_F_key (GtkAction* action, DenemoScriptParam *param)
  *
  */
 void
-go_to_G_key (GtkAction* action, DenemoScriptParam *param)
+change_or_append_G_key (DenemoAction* action, DenemoScriptParam *param)
 {
-  Denemo.project->last_source = INPUTKEYBOARD;
-  shiftcursor (Denemo.project, 4);
+  change_or_append_x_key (4);
 }
 
 
@@ -500,6 +501,9 @@ octave_shift_key (DenemoScriptParam *param, gint amount)
                   thenote = nearestnote (Denemo.project->movement->currentobject->data, Denemo.project->movement->cursor_y);
                   if (thenote)
                     ((note *) thenote->data)->directives = direcs;
+                    
+                  Denemo.project->movement->staffletter_y  = offsettonumber (Denemo.project->movement->cursor_y);
+                    
                   Denemo.project->movement->undo_guard--;
                   score_status (Denemo.project, TRUE);
                 }
@@ -516,7 +520,7 @@ octave_shift_key (DenemoScriptParam *param, gint amount)
  * Move cursor an octave up
  */
 void
-octave_up_key (GtkAction* action, DenemoScriptParam *param)
+octave_up_key (DenemoAction* action, DenemoScriptParam *param)
 {
   octave_shift_key (param, 7);
 }
@@ -528,7 +532,7 @@ octave_up_key (GtkAction* action, DenemoScriptParam *param)
  * Move cursor an octave down
  */
 void
-octave_down_key (GtkAction* action, DenemoScriptParam *param)
+octave_down_key (DenemoAction* action, DenemoScriptParam *param)
 {
   octave_shift_key (param, -7);
 }
@@ -550,43 +554,18 @@ default_mode (DenemoScriptParam *param)
 
 
 
-/**
- * Toggle into rest mode
- *
- */
-void
-rest_toggle_key (GtkAction* action, DenemoScriptParam *param)
-{
-  GtkAction *mode = gtk_ui_manager_get_action (Denemo.ui_manager, "/MainMenu/ModeMenu/Rest");
-  gtk_action_activate (mode);
-  displayhelper (Denemo.project);
-  score_status(Denemo.project, TRUE);
-}
-
-/**
- * Toggle blank mode FIXME bitfields!!!
- *
- */
-void
-toggle_blank (GtkAction* action, DenemoScriptParam *param)
-{
-  GtkAction *mode = gtk_ui_manager_get_action (Denemo.ui_manager, "/MainMenu/ModeMenu/Blank");
-  gtk_action_activate (mode);
-  displayhelper (Denemo.project);
-  score_status(Denemo.project, TRUE);
-}
 
 /**
  * Add measure to end of staff / score
  */
 void
-append_measure_key (GtkAction* action, DenemoScriptParam *param)
+append_measure_key (DenemoAction* action, DenemoScriptParam *param)
 {
   appendmeasures (Denemo.project->movement, 1);
 }
 
 void
-append_measure_score (GtkAction* action, DenemoScriptParam *param)
+append_measure_score (DenemoAction* action, DenemoScriptParam *param)
 {
   appendmeasurestoentirescore (Denemo.project->movement, 1);
 }
@@ -595,71 +574,71 @@ append_measure_score (GtkAction* action, DenemoScriptParam *param)
  * Insert measure at the current
  */
 void
-insert_measure_key (GtkAction* action, DenemoScriptParam *param)
+insert_measure_key (DenemoAction* action, DenemoScriptParam *param)
 {
   dnm_insertmeasures (Denemo.project->movement, 1);
 }
 
-void
-insert_chord_xkey (gint duration, DenemoScriptParam *param)
+static void
+insert_chord_xdur (gint duration, DenemoScriptParam *param)
 {
-  dnm_insertnote (Denemo.project, duration, Denemo.project->mode, FALSE);
+  dnm_insertnote (Denemo.project, duration, Denemo.project->mode, FALSE);//gets it wrong
   displayhelper (Denemo.project);
   score_status(Denemo.project, TRUE);
 }
 
 void
-insert_chord_0key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_0key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(0, param);
+  insert_chord_xdur(0, param);
 }
 
 void
-insert_chord_1key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_1key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(1, param);
+  insert_chord_xdur(1, param);
 }
 
 void
-insert_chord_2key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_2key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(2, param);
+  insert_chord_xdur(2, param);
 }
 
 void
-insert_chord_3key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_3key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(3, param);
+  insert_chord_xdur(3, param);
 }
 
 void
-insert_chord_4key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_4key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(4, param);
+  insert_chord_xdur(4, param);
 }
 
 void
-insert_chord_5key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_5key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(5, param);
+  insert_chord_xdur(5, param);
 }
 
 void
-insert_chord_6key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_6key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(6, param);
+  insert_chord_xdur(6, param);
 }
 
 void
-insert_chord_7key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_7key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(7, param);
+  insert_chord_xdur(7, param);
 }
 
 void
-insert_chord_8key (GtkAction* action, DenemoScriptParam *param)
+insert_chord_8key (DenemoAction* action, DenemoScriptParam *param)
 {
-  insert_chord_xkey(8, param);
+  insert_chord_xdur(8, param);
 }
 
 void
@@ -672,55 +651,55 @@ insert_rest_xkey(gint duration, DenemoScriptParam* param)
 
 
 void
-insert_rest_0key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_0key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(0, param);
 }
 
 void
-insert_rest_1key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_1key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(1, param);
 }
 
 void
-insert_rest_2key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_2key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(2, param);
 }
 
 void
-insert_rest_3key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_3key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(3, param);
 }
 
 void
-insert_rest_4key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_4key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(4, param);
 }
 
 void
-insert_rest_5key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_5key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(5, param);
 }
 
 void
-insert_rest_6key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_6key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(6, param);
 }
 
 void
-insert_rest_7key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_7key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(7, param);
 }
 
 void
-insert_rest_8key (GtkAction* action, DenemoScriptParam *param)
+insert_rest_8key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_rest_xkey(8, param);
 }
@@ -734,67 +713,67 @@ insert_blankchord_xkey (gint duration, DenemoScriptParam *param)
 }
 
 void
-insert_blankchord_0key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_0key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(0, param);
 }
 
 void
-insert_blankchord_1key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_1key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(1, param);
 }
 
 void
-insert_blankchord_2key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_2key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(2, param);
 }
 
 void
-insert_blankchord_3key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_3key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(3, param);
 }
 
 void
-insert_blankchord_4key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_4key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(4, param);
 }
 
 void
-insert_blankchord_5key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_5key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(5, param);
 }
 
 void
-insert_blankchord_6key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_6key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(6, param);
 }
 
 void
-insert_blankchord_7key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_7key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(7, param);
 }
 
 void
-insert_blankchord_8key (GtkAction* action, DenemoScriptParam *param)
+insert_blankchord_8key (DenemoAction* action, DenemoScriptParam *param)
 {
   insert_blankchord_xkey(8, param);
 }
 
 gboolean
-add_tone_key (GtkAction* action, DenemoScriptParam *param)
+add_note_to_chord (DenemoAction* action, DenemoScriptParam *param)
 {
   return insert_chordnote (Denemo.project);
 }
 
 gboolean
-remove_tone_key (GtkAction* action, DenemoScriptParam *param)
+delete_note_from_chord (DenemoAction* action, DenemoScriptParam *param)
 {
   return delete_chordnote (Denemo.project);
 }
@@ -803,7 +782,7 @@ remove_tone_key (GtkAction* action, DenemoScriptParam *param)
 // deletes the object before the cursor. If the measure is empty it moves to the end of the previous measure and calls itself.
 // after deleting an object it backs-up on any rhythm pattern being followed.
 void
-deletepreviousobject (GtkAction* action, DenemoScriptParam *param)
+deletepreviousobject (DenemoAction* action, DenemoScriptParam *param)
 {
 
   /* remove the object preceding the cursor, within the current measure */
@@ -862,35 +841,37 @@ deletepreviousobject (GtkAction* action, DenemoScriptParam *param)
 }
 
 void
-sharpen_key (GtkAction* action, DenemoScriptParam *param)
+sharpen_note (DenemoAction* action, DenemoScriptParam *param)
+{
+    incrementenshift (Denemo.project, 1);
+}
+void
+set_stem_up (DenemoAction* action, DenemoScriptParam *param)
 {
   DenemoObject *curmudelaobj = (DenemoObject *) (Denemo.project->movement->currentobject ? Denemo.project->movement->currentobject->data : NULL);
 
   if (curmudelaobj && curmudelaobj->type == STEMDIRECTIVE)
     change_stem_directive (Denemo.project->movement, DENEMO_STEMUP);
-  else
-    incrementenshift (Denemo.project, 1);
 }
 
+
 void
-stem_up (GtkAction* action, DenemoScriptParam *param)
+flatten_note (DenemoAction* action, DenemoScriptParam *param)
 {
-  sharpen_key (action, param);
+    incrementenshift (Denemo.project, -1);
 }
-
 void
-flatten_key (GtkAction* action, DenemoScriptParam *param)
+set_stem_down (DenemoAction* action, DenemoScriptParam *param)
 {
   DenemoObject *curmudelaobj = (DenemoObject *) (Denemo.project->movement->currentobject ? Denemo.project->movement->currentobject->data : NULL);
 
   if (curmudelaobj && curmudelaobj->type == STEMDIRECTIVE)
     change_stem_directive (Denemo.project->movement, DENEMO_STEMDOWN);
-  else
-    incrementenshift (Denemo.project, -1);
 }
 
+
 void
-pending_sharpen (GtkAction* action, DenemoScriptParam *param)
+pending_sharpen (DenemoAction* action, DenemoScriptParam *param)
 {
   Denemo.project->movement->pending_enshift++;
   if (Denemo.project->movement->pending_enshift > 2)
@@ -900,7 +881,7 @@ pending_sharpen (GtkAction* action, DenemoScriptParam *param)
 }
 
 void
-pending_flatten (GtkAction* action, DenemoScriptParam *param)
+pending_flatten (DenemoAction* action, DenemoScriptParam *param)
 {
   Denemo.project->movement->pending_enshift--;
   if (Denemo.project->movement->pending_enshift < -2)
@@ -909,15 +890,11 @@ pending_flatten (GtkAction* action, DenemoScriptParam *param)
   score_status(Denemo.project, TRUE);
 }
 
-void
-stem_down (GtkAction* action, DenemoScriptParam *param)
-{
-  flatten_key (action, param);
-}
+
 
 /* insert a duplicate note and tie to it */
 void
-tie_notes_key (GtkAction* action, DenemoScriptParam *param)
+tie_notes_key (DenemoAction* action, DenemoScriptParam *param)
 {
   DenemoObject *curObj = (DenemoObject *) (Denemo.project->movement->currentobject ? Denemo.project->movement->currentobject->data : NULL);
 
@@ -948,20 +925,20 @@ tie_notes_key (GtkAction* action, DenemoScriptParam *param)
 }
 
 void
-add_dot_key (GtkAction* action, DenemoScriptParam *param)
+add_dot_key (DenemoAction* action, DenemoScriptParam *param)
 {
   changedots (Denemo.project->movement, 1);
 }
 
 void
-remove_dot_key (GtkAction* action, DenemoScriptParam *param)
+remove_dot_key (DenemoAction* action, DenemoScriptParam *param)
 {
   changedots (Denemo.project->movement, -1);
 }
 
 
 void
-force_cautionary (GtkAction* action, DenemoScriptParam *param)
+force_cautionary (DenemoAction* action, DenemoScriptParam *param)
 {
   DenemoObject *theobj = Denemo.project->movement->currentobject ? (DenemoObject *) Denemo.project->movement->currentobject->data : NULL;
   if (theobj && theobj->type == CHORD)
@@ -969,7 +946,7 @@ force_cautionary (GtkAction* action, DenemoScriptParam *param)
 }
 
 void
-change_pitch (GtkAction* action, DenemoScriptParam *param)
+change_pitch (DenemoAction* action, DenemoScriptParam *param)
 {
   if (Denemo.project->mode & INPUTEDIT)
     {
@@ -978,9 +955,6 @@ change_pitch (GtkAction* action, DenemoScriptParam *param)
       delete_chordnote (Denemo.project);
       insert_chordnote (Denemo.project);
     }
-  // addtone(theobj, si->cursor_y, si->cursoraccs[si->staffletter_y],
-  //       si->cursorclef);
-
 }
 
 /*******************************************************************************
@@ -989,32 +963,24 @@ change_pitch (GtkAction* action, DenemoScriptParam *param)
 
 void InsertRest(gint duration){
   highlight_rest(Denemo.project, duration);
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTINSERT|INPUTREST;
-  insert_chord_xkey(duration, NULL);
-  Denemo.project->mode = mode;
+  dnm_insertnote (Denemo.project, duration, INPUTREST, TRUE);
   score_status(Denemo.project, TRUE);
   displayhelper(Denemo.project);
 }
 
 void InsertDur(gint duration){
   highlight_duration(Denemo.project, duration);
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTINSERT|INPUTNORMAL;
-  insert_chord_xkey(duration, NULL);
-  Denemo.project->mode = mode;
+  dnm_insertnote (Denemo.project, duration,  INPUTNORMAL, FALSE);
+  displayhelper (Denemo.project);
   score_status(Denemo.project, TRUE);
-  displayhelper(Denemo.project);
 }
 
 void ChangeDur(gint duration){
-  gint mode = Denemo.project->mode;
+  
   gboolean appending = Denemo.project->movement->cursor_appending;
   if(appending)
     movecursorleft(NULL, NULL);
-  Denemo.project->mode = INPUTEDIT|INPUTNORMAL;
-  insert_chord_xkey(duration, NULL);
-  Denemo.project->mode = mode;
+  change_duration(duration);
   if(appending)
     movecursorright(NULL, NULL);
   score_status(Denemo.project, TRUE);
@@ -1025,33 +991,32 @@ void SetDur(gint duration){
   highlight_duration(Denemo.project, duration);
 }
 
-void Dur (gint duration) {
-  DenemoProject *gui = Denemo.project;
- if(Denemo.project->mode&INPUTINSERT)
-   highlight_duration(Denemo.project, duration);
- else
- if( !(Denemo.project->mode&INPUTRHYTHM) && (Denemo.project->mode&INPUTEDIT) && (!Denemo.project->movement->cursor_appending))
-   ChangeDur (duration);
-else {
- insert_chord_xkey(duration, NULL);
-   highlight_duration(Denemo.project, duration);
-  score_status(Denemo.project, TRUE);
- displayhelper(Denemo.project);
- }
+//called by the commands (d-0) (d-1) etc
+static void Dur (gint duration) {
+    insert_chord_xdur(duration, NULL);
+    highlight_duration(Denemo.project, duration);
+    score_status(Denemo.project, TRUE);
+    displayhelper(Denemo.project);
 }
 
 /*******************************************************************************
 * NOTE COMMANDS
 ******************************************************************************/
+static change_note_to (gchar note)//CHECK executing (d-ChangeToA)
+{
+  gint mode = Denemo.project->mode;
+  Denemo.project->last_source = INPUTKEYBOARD;
+  edit_or_append_pitch (((note + 5 - 'A') % 7), FALSE);
+  Denemo.project->mode = mode;
+}
+
 
 void ChangeTo(gchar note){
   gboolean appending = Denemo.project->movement->cursor_appending;
   if(appending)
     movecursorleft(NULL, NULL);
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTEDIT|INPUTNORMAL;
-  go_to_key(note, NULL);
-  Denemo.project->mode = mode;
+
+  change_note_to (note);
   if(appending)
     movecursorright(NULL, NULL);
   score_status(Denemo.project, TRUE);
@@ -1059,280 +1024,270 @@ void ChangeTo(gchar note){
 }
 
 void MoveTo(gchar note){
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTCLASSIC|INPUTNORMAL;
-  go_to_key(note, NULL);
-  Denemo.project->mode = mode;
+  move_to_note_by_command (note);
   displayhelper(Denemo.project);
 }
 
 void Insert(gchar note){
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTINSERT|INPUTNORMAL;
-  go_to_key(note, NULL);
-  Denemo.project->mode = mode;
+
+  insert_note_by_command (note);
   score_status(Denemo.project, TRUE);
   displayhelper(Denemo.project);
 }
 
 void AddNote(gchar note){
   movecursorright(NULL, NULL);
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTINSERT|INPUTNORMAL;
-  go_to_key(note, NULL);
-  Denemo.project->mode = mode;
+  insert_note_by_command (note);
   movecursorleft(NULL, NULL);
   score_status(Denemo.project, TRUE);
   displayhelper(Denemo.project);
 }
 
-void Add(gchar note){
-  gint mode = Denemo.project->mode;
-  Denemo.project->mode = INPUTCLASSIC|INPUTNORMAL;
-  go_to_key(note, NULL);
-  add_tone_key(NULL, NULL);
-  Denemo.project->mode = mode;
+void Add(gchar note){ //AddA etc
+  Denemo.project->last_source = INPUTKEYBOARD;
+  move_to_pitch (Denemo.project, ((note + 5 - 'A') % 7));
+  insert_chordnote (Denemo.project);
   score_status(Denemo.project, TRUE);
   displayhelper(Denemo.project);
 }
 
-void Dur0(GtkAction *action, gpointer param) {
+void Dur0(DenemoAction *action, gpointer param) {
   Dur(0);
 }
-void ChangeDur0(GtkAction *action, gpointer param){
+void ChangeDur0(DenemoAction *action, gpointer param){
   ChangeDur(0);
 }
-void InsertDur0(GtkAction *action, gpointer param){
+void InsertDur0(DenemoAction *action, gpointer param){
   InsertDur(0);
 }
-void InsertRest0(GtkAction *action, gpointer param){
+void InsertRest0(DenemoAction *action, gpointer param){
   InsertRest(0);
 }
-void SetDur0(GtkAction *action, gpointer param){
+void SetDur0(DenemoAction *action, gpointer param){
   SetDur(0);
 }
-void Dur1(GtkAction *action, gpointer param) {
+void Dur1(DenemoAction *action, gpointer param) {
   Dur(1);
 }
-void ChangeDur1(GtkAction *action, gpointer param){
+void ChangeDur1(DenemoAction *action, gpointer param){
   ChangeDur(1);
 }
-void InsertDur1(GtkAction *action, gpointer param){
+void InsertDur1(DenemoAction *action, gpointer param){
   InsertDur(1);
 }
-void InsertRest1(GtkAction *action, gpointer param){
+void InsertRest1(DenemoAction *action, gpointer param){
   InsertRest(1);
 }
-void SetDur1(GtkAction *action, gpointer param){
+void SetDur1(DenemoAction *action, gpointer param){
   SetDur(1);
 }
-void Dur2(GtkAction *action, gpointer param) {
+void Dur2(DenemoAction *action, gpointer param) {
   Dur(2);
 }
-void ChangeDur2(GtkAction *action, gpointer param){
+void ChangeDur2(DenemoAction *action, gpointer param){
   ChangeDur(2);
 }
-void InsertDur2(GtkAction *action, gpointer param){
+void InsertDur2(DenemoAction *action, gpointer param){
   InsertDur(2);
 }
-void InsertRest2(GtkAction *action, gpointer param){
+void InsertRest2(DenemoAction *action, gpointer param){
   InsertRest(2);
 }
-void SetDur2(GtkAction *action, gpointer param){
+void SetDur2(DenemoAction *action, gpointer param){
   SetDur(2);
 }
-void Dur3(GtkAction *action, gpointer param) {
+void Dur3(DenemoAction *action, gpointer param) {
   Dur(3);
 }
-void ChangeDur3(GtkAction *action, gpointer param){
+void ChangeDur3(DenemoAction *action, gpointer param){
   ChangeDur(3);
 }
-void InsertDur3(GtkAction *action, gpointer param){
+void InsertDur3(DenemoAction *action, gpointer param){
   InsertDur(3);
 }
-void InsertRest3(GtkAction *action, gpointer param){
+void InsertRest3(DenemoAction *action, gpointer param){
   InsertRest(3);
 }
-void SetDur3(GtkAction *action, gpointer param){
+void SetDur3(DenemoAction *action, gpointer param){
   SetDur(3);
 }
-void Dur4(GtkAction *action, gpointer param) {
+void Dur4(DenemoAction *action, gpointer param) {
   Dur(4);
 }
-void ChangeDur4(GtkAction *action, gpointer param){
+void ChangeDur4(DenemoAction *action, gpointer param){
   ChangeDur(4);
 }
-void InsertDur4(GtkAction *action, gpointer param){
+void InsertDur4(DenemoAction *action, gpointer param){
   InsertDur(4);
 }
-void InsertRest4(GtkAction *action, gpointer param){
+void InsertRest4(DenemoAction *action, gpointer param){
   InsertRest(4);
 }
-void SetDur4(GtkAction *action, gpointer param){
+void SetDur4(DenemoAction *action, gpointer param){
   SetDur(4);
 }
-void Dur5(GtkAction *action, gpointer param) {
+void Dur5(DenemoAction *action, gpointer param) {
   Dur(5);
 }
-void ChangeDur5(GtkAction *action, gpointer param){
+void ChangeDur5(DenemoAction *action, gpointer param){
   ChangeDur(5);
 }
-void InsertDur5(GtkAction *action, gpointer param){
+void InsertDur5(DenemoAction *action, gpointer param){
   InsertDur(5);
 }
-void InsertRest5(GtkAction *action, gpointer param){
+void InsertRest5(DenemoAction *action, gpointer param){
   InsertRest(5);
 }
-void SetDur5(GtkAction *action, gpointer param){
+void SetDur5(DenemoAction *action, gpointer param){
   SetDur(5);
 }
-void Dur6(GtkAction *action, gpointer param) {
+void Dur6(DenemoAction *action, gpointer param) {
   Dur(6);
 }
-void ChangeDur6(GtkAction *action, gpointer param){
+void ChangeDur6(DenemoAction *action, gpointer param){
   ChangeDur(6);
 }
-void InsertDur6(GtkAction *action, gpointer param){
+void InsertDur6(DenemoAction *action, gpointer param){
   InsertDur(6);
 }
-void InsertRest6(GtkAction *action, gpointer param){
+void InsertRest6(DenemoAction *action, gpointer param){
   InsertRest(6);
 }
-void SetDur6(GtkAction *action, gpointer param){
+void SetDur6(DenemoAction *action, gpointer param){
   SetDur(6);
 }
-void Dur7(GtkAction *action, gpointer param) {
+void Dur7(DenemoAction *action, gpointer param) {
   Dur(7);
 }
-void ChangeDur7(GtkAction *action, gpointer param){
+void ChangeDur7(DenemoAction *action, gpointer param){
   ChangeDur(7);
 }
-void InsertDur7(GtkAction *action, gpointer param){
+void InsertDur7(DenemoAction *action, gpointer param){
   InsertDur(7);
 }
-void InsertRest7(GtkAction *action, gpointer param){
+void InsertRest7(DenemoAction *action, gpointer param){
   InsertRest(7);
 }
-void SetDur7(GtkAction *action, gpointer param){
+void SetDur7(DenemoAction *action, gpointer param){
   SetDur(7);
 }
-void Dur8(GtkAction *action, gpointer param) {
+void Dur8(DenemoAction *action, gpointer param) {
   Dur(8);
 }
-void ChangeDur8(GtkAction *action, gpointer param){
+void ChangeDur8(DenemoAction *action, gpointer param){
   ChangeDur(8);
 }
-void InsertDur8(GtkAction *action, gpointer param){
+void InsertDur8(DenemoAction *action, gpointer param){
   InsertDur(8);
 }
-void InsertRest8(GtkAction *action, gpointer param){
+void InsertRest8(DenemoAction *action, gpointer param){
   InsertRest(8);
 }
-void SetDur8(GtkAction *action, gpointer param){
+void SetDur8(DenemoAction *action, gpointer param){
   SetDur(8);
 }
-void InsertA(GtkAction *action, gpointer param){
+void InsertA(DenemoAction *action, gpointer param){
   Insert('A');
 }
-void AddNoteA(GtkAction *action, gpointer param){
+void AddNoteA(DenemoAction *action, gpointer param){
   AddNote('A');
 }
-void AddA(GtkAction *action, gpointer param){
+void AddA(DenemoAction *action, gpointer param){
   Add('A');
 }
-void ChangeToA(GtkAction *action, gpointer param){
+void ChangeToA(DenemoAction *action, gpointer param){
   ChangeTo('A');
 }
-void MoveToA(GtkAction *action, gpointer param){
+void MoveToA(DenemoAction *action, gpointer param){
   MoveTo('A');
 }
-void InsertB(GtkAction *action, gpointer param){
+void InsertB(DenemoAction *action, gpointer param){
   Insert('B');
 }
-void AddNoteB(GtkAction *action, gpointer param){
+void AddNoteB(DenemoAction *action, gpointer param){
   AddNote('B');
 }
-void AddB(GtkAction *action, gpointer param){
+void AddB(DenemoAction *action, gpointer param){
   Add('B');
 }
-void ChangeToB(GtkAction *action, gpointer param){
+void ChangeToB(DenemoAction *action, gpointer param){
   ChangeTo('B');
 }
-void MoveToB(GtkAction *action, gpointer param){
+void MoveToB(DenemoAction *action, gpointer param){
   MoveTo('B');
 }
-void InsertC(GtkAction *action, gpointer param){
+void InsertC(DenemoAction *action, gpointer param){
   Insert('C');
 }
-void AddNoteC(GtkAction *action, gpointer param){
+void AddNoteC(DenemoAction *action, gpointer param){
   AddNote('C');
 }
-void AddC(GtkAction *action, gpointer param){
+void AddC(DenemoAction *action, gpointer param){
   Add('C');
 }
-void ChangeToC(GtkAction *action, gpointer param){
+void ChangeToC(DenemoAction *action, gpointer param){
   ChangeTo('C');
 }
-void MoveToC(GtkAction *action, gpointer param){
+void MoveToC(DenemoAction *action, gpointer param){
   MoveTo('C');
 }
-void InsertD(GtkAction *action, gpointer param){
+void InsertD(DenemoAction *action, gpointer param){
   Insert('D');
 }
-void AddNoteD(GtkAction *action, gpointer param){
+void AddNoteD(DenemoAction *action, gpointer param){
   AddNote('D');
 }
-void AddD(GtkAction *action, gpointer param){
+void AddD(DenemoAction *action, gpointer param){
   Add('D');
 }
-void ChangeToD(GtkAction *action, gpointer param){
+void ChangeToD(DenemoAction *action, gpointer param){
   ChangeTo('D');
 }
-void MoveToD(GtkAction *action, gpointer param){
+void MoveToD(DenemoAction *action, gpointer param){
   MoveTo('D');
 }
-void InsertE(GtkAction *action, gpointer param){
+void InsertE(DenemoAction *action, gpointer param){
   Insert('E');
 }
-void AddNoteE(GtkAction *action, gpointer param){
+void AddNoteE(DenemoAction *action, gpointer param){
   AddNote('E');
 }
-void AddE(GtkAction *action, gpointer param){
+void AddE(DenemoAction *action, gpointer param){
   Add('E');
 }
-void ChangeToE(GtkAction *action, gpointer param){
+void ChangeToE(DenemoAction *action, gpointer param){
   ChangeTo('E');
 }
-void MoveToE(GtkAction *action, gpointer param){
+void MoveToE(DenemoAction *action, gpointer param){
   MoveTo('E');
 }
-void InsertF(GtkAction *action, gpointer param){
+void InsertF(DenemoAction *action, gpointer param){
   Insert('F');
 }
-void AddNoteF(GtkAction *action, gpointer param){
+void AddNoteF(DenemoAction *action, gpointer param){
   AddNote('F');
 }
-void AddF(GtkAction *action, gpointer param){
+void AddF(DenemoAction *action, gpointer param){
   Add('F');
 }
-void ChangeToF(GtkAction *action, gpointer param){
+void ChangeToF(DenemoAction *action, gpointer param){
   ChangeTo('F');
 }
-void MoveToF(GtkAction *action, gpointer param){
+void MoveToF(DenemoAction *action, gpointer param){
   MoveTo('F');
 }
-void InsertG(GtkAction *action, gpointer param){
+void InsertG(DenemoAction *action, gpointer param){
   Insert('G');
 }
-void AddNoteG(GtkAction *action, gpointer param){
+void AddNoteG(DenemoAction *action, gpointer param){
   AddNote('G');
 }
-void AddG(GtkAction *action, gpointer param){
+void AddG(DenemoAction *action, gpointer param){
   Add('G');
 }
-void ChangeToG(GtkAction *action, gpointer param){
+void ChangeToG(DenemoAction *action, gpointer param){
   ChangeTo('G');
 }
-void MoveToG(GtkAction *action, gpointer param){
+void MoveToG(DenemoAction *action, gpointer param){
   MoveTo('G');
 }
