@@ -15,8 +15,93 @@
 #include "command/score.h"
 #include "display/draw.h"
 #include "command/lilydirectives.h"
+
+// movement->lyricsbox is a GtkVBox containing GtkNotebook s for each staff with verses. The verses are GtkTextView s  notebook
+//staff->verse_views is a list of GtkTextView which are packed in a GtkScrolledWindow
+//so  movement->lyricsbox contains Notebook->ScrolledWindow->TextView
+//the text of the verses is stored in staff->verses
 static GtkWidget *DummyVerse;   /* a non-existent verse */
 static gint SkipCount = 0;      //count of syllables to be skipped
+
+
+gboolean
+denemo_pango_scan_string (const char **pos, GString *out)
+{
+  const char *p = *pos;
+
+  while (g_ascii_isspace (*p))
+    p++;
+
+  if (G_UNLIKELY (!*p))
+    return FALSE;
+  else if (*p == '"')
+    {
+      gboolean quoted = FALSE;
+      g_string_truncate (out, 0);
+
+      p++;
+
+      while (TRUE)
+    {
+      if (quoted)
+        {
+          int c = *p;
+
+          switch (c)
+        {
+        case '\0':
+          return FALSE;
+        case 'n':
+          c = '\n';
+          break;
+        case 't':
+          c = '\t';
+          break;
+        default:
+          break;
+        }
+
+          quoted = FALSE;
+          g_string_append_c (out, c);
+        }
+      else
+        {
+          switch (*p)
+        {
+        case '\0':
+          return FALSE;
+        case '\\':
+          quoted = TRUE;
+          break;
+        case '"':
+          p++;
+          goto done;
+        default:
+          g_string_append_c (out, *p);
+          break;
+        }
+        }
+      p++;
+    }
+    done:
+      ;
+    }
+  else
+    {
+      g_string_truncate (out, 0);
+
+      while (*p && !g_ascii_isspace (*p))
+    {
+      g_string_append_c (out, *p);
+      p++;
+    }
+    }
+
+  *pos = p;
+
+  return TRUE;
+}
+
 GtkWidget *
 verse_get_current_view (DenemoStaff * staff)
 {
@@ -27,13 +112,27 @@ verse_get_current_view (DenemoStaff * staff)
   return staff->current_verse_view->data;
 }
 
-void
-verse_set_current (DenemoStaff * staff, guint id)
+gboolean
+verse_set_current (DenemoStaff * staff, gint id)
 {
-  if (staff)
-    staff->current_verse_view = g_list_nth (staff->verse_views, id);
+if (staff && staff->verse_views && (id >= 0) && (id < g_list_length (staff->verse_views)))
+    {
+      staff->current_verse_view = g_list_nth (staff->verse_views, id);
+      GtkWidget *w = staff->verse_views->data;
+      GtkWidget *notebook = gtk_widget_get_parent (gtk_widget_get_parent (w));
+      if(notebook) gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), id);
+      return TRUE;
+    }
   else
-    g_debug ("Trying to set a verse on an invalid staff");
+    return FALSE;
+}
+
+static void point_to_verse (DenemoStaff * staff, guint id)
+{
+  if (staff && staff->verse_views && (id >= 0) && (id < g_list_length (staff->verse_views)))
+    {
+      staff->current_verse_view = g_list_nth (staff->verse_views, id);
+  }
 }
 
 gint
@@ -47,7 +146,7 @@ previous_verse (void)
 {
   DenemoStaff *thestaff = Denemo.project->movement->currentstaff->data;
   GtkWidget *w = thestaff->verse_views->data;
-  GtkNotebook *notebook = gtk_widget_get_parent (gtk_widget_get_parent (w));
+  GtkNotebook *notebook = (GtkNotebook *)gtk_widget_get_parent (gtk_widget_get_parent (w));
   gtk_notebook_prev_page (notebook);
 }
 
@@ -56,7 +155,7 @@ next_verse (void)
 {
   DenemoStaff *thestaff = Denemo.project->movement->currentstaff->data;
   GtkWidget *w = thestaff->verse_views->data;
-  GtkNotebook *notebook = gtk_widget_get_parent (gtk_widget_get_parent (w));
+  GtkNotebook *notebook = (GtkNotebook *)gtk_widget_get_parent (gtk_widget_get_parent (w));
   gtk_notebook_next_page (notebook);
 }
 
@@ -137,7 +236,7 @@ static void
 switch_page (GtkNotebook * notebook, gpointer dummy, guint pagenum, DenemoStaff * staff)
 {
   draw_score_area ();
-  verse_set_current (staff, pagenum);
+  point_to_verse (staff, pagenum);
 }
 
 //scans *next for a syllable putting the syllable into gs and moving *next to the address beyond the syllable
@@ -153,16 +252,16 @@ scan_syllable (gchar ** next, GString * gs)
       g_string_assign (gs, "(skip)");
       return TRUE;
     }
-  result = pango_scan_string ((const char **) next, gs);
+  result = denemo_pango_scan_string ((const char **) next, gs);
   if (result && (*gs->str == '\\') && (*(gs->str + 1) != '\\') && (*(gs->str + 1) != '\"'))
     {
       //if it is \repeat unfold n \skip 1 put the number n into SkipCount and return a space indicator
       if (!strcmp (gs->str, "\\repeat"))
         {
-          result = pango_scan_string ((const char **) next, gs);
+          result = denemo_pango_scan_string ((const char **) next, gs);
           if (result && (!strcmp (gs->str, "unfold")))
             {
-              result = pango_scan_string ((const char **) next, gs);
+              result = denemo_pango_scan_string ((const char **) next, gs);
               if (result)
                 SkipCount = atoi (gs->str);
               while (**next && **next != '\n')
@@ -478,7 +577,7 @@ add_verse_to_staff (DenemoMovement * movement, DenemoStaff * staff)
   gtk_widget_show_all (gtk_widget_get_parent (textview));
   staff->verse_views = g_list_append (staff->verse_views, textview);
   guint pos = g_list_position (staff->verse_views, g_list_last (staff->verse_views));
-  verse_set_current (staff, pos);
+  point_to_verse (staff, pos);
   gint pagenum = gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gtk_widget_get_parent (textview), NULL);
   gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), pagenum);
   gchar *tablabel = g_strdup_printf (_("Verse %d"), pagenum + 1);
@@ -500,17 +599,54 @@ add_verse_to_staff (DenemoMovement * movement, DenemoStaff * staff)
   gdk_color_parse ("gray", &thecolor);
   gtk_widget_modify_bg (verse_view, GTK_STATE_NORMAL, &thecolor);
 #else
-  GdkRGBA grayed = { 0.5, 0.5, 0.5, 1.0 };      //background away from letters, when not receiving input
-  GdkRGBA white = { 0.7, 0.7, 0.7, 1.0 };       //background of letters
-  gtk_widget_override_background_color (GTK_WIDGET (verse_view), GTK_STATE_FLAG_FOCUSED, &white);
-  gtk_widget_override_background_color (GTK_WIDGET (verse_view), GTK_STATE_FLAG_NORMAL, &grayed);
+{
+GtkCssProvider *gcp;
+GtkStyleContext *gsc;
+gsc = gtk_widget_get_style_context(GTK_WIDGET (verse_view));
+gchar *str = "GtkTextView {background-color: rgb(128,128,80);}"; //this overrides the focus one unless it is before.
+gcp= gtk_css_provider_new();
+gtk_css_provider_load_from_data(gcp, str, -1, 0);
+gtk_style_context_add_provider(gsc, GTK_STYLE_PROVIDER(gcp), 
+    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+str = "GtkTextView:focus {background-color: rgb(128,128,0);}"; //this is effective
+gcp= gtk_css_provider_new();
+gtk_css_provider_load_from_data(gcp, str, -1, 0);
+gtk_style_context_add_provider(gsc, GTK_STYLE_PROVIDER(gcp), 
+    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    
+str =  "GtkTextView:selected {background-color: rgb(200,128,0);}";
+gcp= gtk_css_provider_new();
+gtk_css_provider_load_from_data(gcp, str, -1, 0);
+gtk_style_context_add_provider(gsc, GTK_STYLE_PROVIDER(gcp), 
+    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+#if ((GTK_MAJOR_VERSION==3) && (GTK_MINOR_VERSION >= 20))
+str = "GtkTextView {caret-color: rgb(200,200,0);}";
+#else
+str = "GtkTextView {-GtkWidget-cursor-color: rgb(200,200,0);}";
 #endif
 
+gcp= gtk_css_provider_new();
+gtk_css_provider_load_from_data(gcp, str, -1, 0);
+gtk_style_context_add_provider(gsc, GTK_STYLE_PROVIDER(gcp), 
+    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
+
+str =  "GtkTextView {-GtkWidget-cursor-aspect-ratio: 0.1;}";
+gcp= gtk_css_provider_new();
+gtk_css_provider_load_from_data(gcp, str, -1, 0);
+gtk_style_context_add_provider(gsc, GTK_STYLE_PROVIDER(gcp), 
+    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+       
+} 
+#endif
+  show_verses ();
   return pos;
 }
 
 void
-add_verse (GtkAction * action, DenemoScriptParam * param)
+add_verse (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   DenemoMovement *movement = project->movement;
@@ -525,35 +661,36 @@ add_verse (GtkAction * action, DenemoScriptParam * param)
 }
 
 void
-delete_verse (GtkAction * action, DenemoScriptParam * param)
+delete_verse (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *gui = Denemo.project;
   DenemoMovement *si = gui->movement;
   if (si->currentstaff)
     {
       DenemoStaff *staff = si->currentstaff->data;
-      if (staff->verses)
+      if (staff->verses && staff->verse_views)
         {
           GtkTextView *verse_view = (GtkTextView *) verse_get_current_view (staff);
+          gint versenum = verse_get_current (staff);
           gchar *verse_text = verse_get_current_text (staff);
-          if (verse_text && verse_view)
+         
+          staff->verse_views = g_list_remove (staff->verse_views, verse_view);
+          staff->verses = g_list_remove (staff->verses, verse_text);
+
+          if (staff->verse_views == NULL)
             {
-              staff->verse_views = g_list_remove (staff->verse_views, verse_view);
-              staff->verses = g_list_remove (staff->verses, verse_text);
-
-              if (staff->verse_views == NULL)
-                {
-                  verse_set_current (staff, 0);
-                  gtk_widget_destroy (gtk_widget_get_parent (gtk_widget_get_parent (GTK_WIDGET (verse_view))));
-                }
-              else
-                gtk_widget_destroy (gtk_widget_get_parent (GTK_WIDGET (verse_view)));
-              // g_print("Children are %p\n",  gtk_container_get_children (GTK_CONTAINER (gtk_container_get_children (GTK_CONTAINER (si->lyricsbox))->data)));
-
-              signal_structural_change (gui);
-              score_status (gui, TRUE);
-              draw_score_area ();
+              staff->current_verse_view = NULL;
+              gtk_widget_destroy (gtk_widget_get_parent (gtk_widget_get_parent (GTK_WIDGET (verse_view))));//destroy notebook and so notebook->scrolled window->text view
             }
+          else
+            gtk_widget_destroy (gtk_widget_get_parent (GTK_WIDGET (verse_view)));
+          // g_print("Children are %p\n",  gtk_container_get_children (GTK_CONTAINER (gtk_container_get_children (GTK_CONTAINER (si->lyricsbox))->data)));
+          if (!verse_set_current (staff, versenum-1))
+            staff->current_verse_view = NULL;// no verses left
+          signal_structural_change (gui);
+          score_status (gui, TRUE);
+          draw_score_area ();
+            
         }
     }
 }
@@ -642,7 +779,7 @@ install_lyrics_preview (DenemoMovement * si, GtkWidget * top_vbox)
         }
       gtk_box_pack_start (GTK_BOX (gtk_paned_get_child2 (GTK_PANED (parent))), si->lyricsbox, TRUE, TRUE, 0);
     }
-  if (Denemo.prefs.lyrics_pane)
+ // if (Denemo.prefs.lyrics_pane)
     gtk_widget_show (si->lyricsbox);
 }
 
