@@ -8,8 +8,8 @@
 #define LYRIC_H
 
 #include <denemo/denemo.h>
-void add_verse (GtkAction * action, DenemoScriptParam * param);
-void delete_verse (GtkAction * action, DenemoScriptParam * param);
+void add_verse (DenemoAction * action, DenemoScriptParam * param);
+void delete_verse (DenemoAction * action, DenemoScriptParam * param);
 void reset_lyrics (DenemoStaff * staff, gint count);
 gchar *get_text_from_view (GtkWidget * textview);
 guint add_verse_to_staff (DenemoMovement * si, DenemoStaff * staff);
@@ -25,7 +25,7 @@ gchar *get_lyrics_for_verse_num (gint number);
 gboolean append_lyrics_for_current_verse (DenemoStaff * thestaff, gchar * text);
 gboolean synchronize_lyric_cursor (gint offset);
 GtkWidget *verse_get_current_view (DenemoStaff * staff);
-void verse_set_current (DenemoStaff * staff, guint id);
+gboolean verse_set_current (DenemoStaff * staff, gint id);
 gint verse_get_current (DenemoStaff * staff);
 void verse_set_current_text (DenemoStaff * staff, gchar * text);
 gchar *verse_get_current_text (DenemoStaff * staff);
