@@ -13,20 +13,20 @@ DenemoObject *get_object (void);
 
 void freeobject (DenemoObject * mudobj);
 
-void display_current_object(void);
+void display_current_object (void);
 
 void update_object_info (void);
 
 void edit_object (void);
-void
-edit_score_properties (void);
-void
-edit_movement_properties (void);
+void edit_score_properties (void);
+void edit_movement_properties (void);
 
 void edit_staff_properties (void);
 
 void edit_voice_properties (void);
 
+void set_modeaccs (gint * accs, gint number, gint mode);
+
 void initkeyaccs (gint * accs, gint number);
 
 //void dnm_setinitialkeysig (DenemoStaff * curstaff, gint tokey, gint type);
