@@ -390,6 +390,8 @@ staff_delete (DenemoProject * project, gboolean interactive)
   if (interactive && (curstaffstruct->context != DENEMO_NONE))
     give_info = TRUE;
   take_snapshot ();
+  if (!Denemo.non_interactive)
+    Denemo.project->movement->undo_guard++;
   gboolean isprimary = (gboolean) (curstaffstruct->voicecontrol & DENEMO_PRIMARY);
   //FIXME free_staff()
 
@@ -450,6 +452,9 @@ staff_delete (DenemoProject * project, gboolean interactive)
 
   if (give_info)
     infodialog (_("The staff deleted had a start/end context; if you still have the staff with the matching end/start context\n then you should remove it (or its context) now.\nSee Staff->properties->context\nYou will not be able to print with miss-matched contexts."));
+
+  if (!Denemo.non_interactive)
+    Denemo.project->movement->undo_guard--;
   return;
 }
 
@@ -524,7 +529,7 @@ g_warning ("Staff fix note heights called uselessly?");
  * @return none
  */
 void
-staff_new_initial (GtkAction * action, DenemoScriptParam * param)
+staff_new_initial (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   while (project->movement->currentstaff && project->movement->currentstaff->prev)
@@ -539,7 +544,7 @@ staff_new_initial (GtkAction * action, DenemoScriptParam * param)
  * @return none
  */
 void
-staff_new_before (GtkAction * action, DenemoScriptParam * param)
+staff_new_before (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   (void) signal_structural_change (project);
@@ -565,7 +570,7 @@ staff_new_before (GtkAction * action, DenemoScriptParam * param)
  * @return none
  */
 void
-staff_new_after (GtkAction * action, DenemoScriptParam * param)
+staff_new_after (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   if (!signal_structural_change (project))
@@ -587,7 +592,7 @@ staff_new_after (GtkAction * action, DenemoScriptParam * param)
  * @return none
  */
 void
-staff_new_last (GtkAction * action, DenemoScriptParam * param)
+staff_new_last (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   while (project->movement->currentstaff && project->movement->currentstaff->next)
@@ -602,7 +607,7 @@ staff_new_last (GtkAction * action, DenemoScriptParam * param)
  * @return none
  */
 void
-staff_new_voice (GtkAction * action, DenemoScriptParam * param)
+staff_new_voice (DenemoAction * action, DenemoScriptParam * param)
 {
   DenemoProject *project = Denemo.project;
   staff_new (project, NEWVOICE, DENEMO_NONE);
