@@ -182,7 +182,7 @@ saveMenuItem (GtkWidget * widget, DenemoAction * action)
 
   command_row *row = NULL;
   keymap_get_command_row (Denemo.map, &row, idx);
-
+  if (!row) return;
   gchar *tooltip = (gchar *) lookup_tooltip_from_idx (Denemo.map, idx);
   gchar *label = (gchar *) lookup_label_from_idx (Denemo.map, idx);
 
@@ -799,6 +799,8 @@ menu_click (GtkWidget * widget, GdkEventButton * event, DenemoAction * action)
   gint idx = lookup_command_from_name (the_keymap, func_name);
   command_row *row = NULL;
   keymap_get_command_row (the_keymap, &row, idx);
+  if (!row)
+    return TRUE;//stop other handlers running
   //g_debug("event button %d, idx %d for %s recording = %d scm = %d\n", event->button, idx, func_name, Denemo.ScriptRecording,g_object_get_data(G_OBJECT(action), "scm") );
   if (event->button != 3)       //Not right click
     if (Denemo.ScriptRecording)
@@ -1031,11 +1033,13 @@ attach_accels_and_callbacks (DenemoAction * action, GtkWidget * proxy)
 
   if (command_idx > -1)
     {
-      keymap_get_command_row (Denemo.map, &row, command_idx);
-      update_accel_labels (Denemo.map, command_idx);
+      if (keymap_get_command_row (Denemo.map, &row, command_idx))
+        {
+          update_accel_labels (Denemo.map, command_idx);
 
-      if (row->hidden)
-        set_visibility_for_action (action, FALSE);
+          if (row->hidden)
+            set_visibility_for_action (action, FALSE);
+        }
     }
 }
 
@@ -1127,13 +1131,12 @@ static void create_palette_for_menu (GtkWidget *menu)
 {
    GList *g, *children = gtk_container_get_children (GTK_CONTAINER(menu));
    GList *palette_names = (GList*)g_object_get_data (G_OBJECT(menu), "labels");
-   gint number = g_list_length (children);
    gchar *palette_name = get_palette_name_from_list (palette_names); 
     DenemoPalette *pal = get_palette (palette_name);
     if(pal==NULL)
         {
-        pal = set_palate_shape (palette_name, FALSE, (number/10) + 1);//strangely named function
-
+        gboolean palette_is_empty = TRUE;
+        pal = set_palette_shape (palette_name, FALSE, 1);
         pal->menu = TRUE;
         for (g=children;g;g=g->next)
             {
@@ -1148,9 +1151,15 @@ static void create_palette_for_menu (GtkWidget *menu)
             script = g_strdup_printf ("(d-%s)", action->name);
              gchar *escaped = g_markup_escape_text (action->label, -1);
             palette_add_button (pal, escaped, action->tooltip, script);
+            palette_is_empty = FALSE;
             g_free (escaped);
             }
         g_list_free (children); 
+        if (palette_is_empty)
+          {
+            delete_palette (pal);
+            warningdialog (_("This menu holds no commands"));
+          }
         }
     else
         gtk_widget_show (gtk_widget_get_parent (pal->box)), gtk_widget_show (pal->box);
@@ -1193,7 +1202,7 @@ void denemo_menusystem_add_menu (gchar *path, gchar *name)
         GtkWidget *item, *parent = denemo_menusystem_get_widget (path);
         if (!parent)
             {
-                g_critical ("No menu in %s", __FILE__);
+                g_critical ("No menu in for path %s, name %s in %s", path, name, __FILE__);
                 return;
             }        
         gchar *label = get_label_for_name (name);
@@ -1425,14 +1434,14 @@ void denemo_action_group_add_radio_actions (void)
                     
 DenemoAction *denemo_menusystem_get_action (gchar *name)  
 {
-  return  (DenemoAction*)g_hash_table_lookup (Actions, name);
+  return  name?(DenemoAction*)g_hash_table_lookup (Actions, name):NULL;
  
 }   
 
 GList* denemo_action_get_proxies (DenemoAction *action)
 {
     
-    return (GList*)g_hash_table_lookup (ActionWidgets, action->name);
+    return action?(GList*)g_hash_table_lookup (ActionWidgets, action->name):NULL;
 }
 
 gchar *denemo_action_get_name (DenemoAction *action) {
@@ -1463,14 +1472,16 @@ static void  toolbar_save_callback (void)
     {file_savewrapper (NULL, NULL);}
 static void  toolbar_print_callback (void)
     {
+#ifndef USE_EVINCE
+  g_debug ("This feature requires denemo to be built with evince");
+#else
     if (!gtk_widget_get_visible ( gtk_widget_get_toplevel (Denemo.printarea)))
         set_toggle (TogglePrintView_STRING, TRUE);
     else
         implement_show_print_view(TRUE);
+#endif
     }
-//static toolbar_printview_callback (void)
-//    {implement_show_print_view(TRUE);}
-//show_print_view(NULL, NULL);} 
+
 static void  toolbar_move_to_start_callback (void)
     {movetostart (NULL, NULL);}    
 static void  toolbar_move_to_end_callback (void)
