@@ -32,7 +32,6 @@
 #define EXCL_WIDTH 3
 #define EXCL_HEIGHT 13
 #define SAMPLERATE (44100) /* arbitrary large figure used if no audio */
-static GdkPixbuf *StaffPixbuf, *StaffPixbufSmall;
 static DenemoObject *Startobj, *Endobj;
 static gboolean layout_needed = TRUE;   //Set FALSE when further call to draw_score(NULL) is not needed.
 static GList *MidiDrawObject;/* a chord used for drawing MIDI recorded notes on the score */
@@ -75,14 +74,6 @@ set_start_and_end_objects_for_draw (void)
     }
 }
 
-static void
-create_tool_pixbuf (void)
-{
-  GtkWidget *widget = gtk_button_new ();
-  StaffPixbuf = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_BUTTON, "denemo");
-  StaffPixbufSmall = gtk_widget_render_icon (widget, GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON, "denemo");//something for highlighting!
-  
-}
 
 
 /**
@@ -100,7 +91,6 @@ scorearea_configure_event (G_GNUC_UNUSED GtkWidget * widget, G_GNUC_UNUSED GdkEv
     {
       MidiDrawObject = g_list_append(NULL, newchord (0, 0, 0));
       chord *thechord = ((DenemoObject*)(MidiDrawObject->data))->object;
-      create_tool_pixbuf ();
       init = TRUE;
     }
 
@@ -524,8 +514,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
 
         if (si->currentstaffnum == itp->staffnum && itp->verse && thechord->notes)
           {
-            
-            if ((!last_tied) && (!itp->slur_stack)
+            if ((!thechord->is_grace) && (!last_tied) && (!itp->slur_stack)
                             && !find_directive (thechord->directives, "MoveRest"))
               {
                 gchar *syllable = (gchar *) next_syllable ();
@@ -1166,31 +1155,7 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
       if (itp->measurenum == si->currentmeasurenum)
         x += measure_transition_offset (si->currentstaffnum == itp->staffnum);
       draw_measure (cr, itp->curmeasure, x, y, gui, itp);
-      if (cr && (Denemo.project->view != DENEMO_PAGE_VIEW) && (si->sources || thestaff->sources) && (si->currentstaffnum == itp->staffnum))
-        {
-          GdkPixbuf *source = (GdkPixbuf *) g_list_nth_data (si->sources ? gui->movement->sources : thestaff->sources, itp->measurenum - 1);
-          if (source)
-            {
-              gdouble width = (gdouble) gdk_pixbuf_get_width (GDK_PIXBUF (source));
-              gdouble height = (gdouble) gdk_pixbuf_get_height (GDK_PIXBUF (source));
-              gdouble scale = GPOINTER_TO_INT (itp->mwidthiterator->data) / width;
-              gint ypos = y + 2 * STAFF_HEIGHT + thestaff->space_below;
-              gint xpos = x;
-              cairo_save (cr);
-              if (scale < 1.0)
-                {               //too large to fit under the measure
-                  cairo_translate (cr, x * (1 - scale), ypos * (1 - scale));
-                  cairo_scale (cr, scale, scale);
-                }
-              else
-                xpos = x - (width - GPOINTER_TO_INT (itp->mwidthiterator->data)) / 2;   //narrow, center it
-              gdk_cairo_set_source_pixbuf (cr, GDK_PIXBUF (source), xpos, ypos);
-              cairo_rectangle (cr, xpos, ypos, width, height);
-              cairo_fill (cr);
-              cairo_restore (cr);
-              itp->source_displayed = TRUE;
-            }
-        }
+ 
 
       x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
 
@@ -1601,7 +1566,6 @@ draw_score (cairo_t * cr)
             continue;
           }
       itp.verse = verse_get_current_view (staff);
-      GdkPixbuf *StaffDirectivesPixbuf = (Denemo.hovering_over_margin_up) ? StaffPixbuf : StaffPixbufSmall;
       if (si->currentstaffnum == itp.staffnum)
         y += staff_transition_offset ();
 
@@ -1879,9 +1843,7 @@ draw_callback (cairo_t * cr)
   /* Clear with an appropriate background color. */
   if (Denemo.project->input_source != INPUTKEYBOARD && Denemo.project->input_source != INPUTMIDI && (Denemo.prefs.overlays || (Denemo.project->input_source == INPUTAUDIO)) && pitch_entry_active (gui))
     {
-      GdkColor col;
-      gdk_color_parse ("lightblue", &col);
-      gdk_cairo_set_source_color (cr, &col);
+      cairo_set_source_rgb (cr, 0xAD/255.0, 0xD8/255.0, 0xE6/255.0);  //light blue
     }
   else if (gtk_widget_has_focus (Denemo.scorearea) && gtk_widget_is_focus (Denemo.scorearea))
     {
