@@ -130,7 +130,7 @@ show_playback_view (void)
 {
     GtkWidget *w = gtk_widget_get_toplevel (Denemo.playbackview);
     if (!gtk_widget_get_visible (w))
-        activate_action ("/MainMenu/ViewMenu/" TogglePlaybackView_STRING);
+        set_toggle (TogglePlaybackView_STRING, TRUE);
     else
         gtk_window_present (GTK_WINDOW (w));
 }
@@ -174,7 +174,7 @@ gboolean attach_timings (void)
     {
         Timing *this = (Timing *)g->data;
         DenemoObject *obj = get_object_at_lilypond (this->line, this->col);
-      //g_print ("at %d %d\n", this->line, this->col);
+        //g_print ("Attaching time %.2f (duration %.2f) (x=%.2f, y-%.2f) at line %d column %d\n",this->time, this->duration, this->x, this->y, this->line, this->col);
             if (obj)
                {
                   obj->earliest_time = this->time;
@@ -337,6 +337,8 @@ playbackview_predraw_event (GtkWidget * widget, GdkEventExpose * event)
 
 static Timing *get_svg_position(gchar *id, GList *ids)
 {
+  gchar *locale = setlocale (LC_ALL, NULL);
+  setlocale (LC_ALL, "C");
   for(;ids;ids=ids->next)
         {//g_print ("Testing %s with %s\n", ids->data, id);
             if (g_str_has_prefix ((gchar*)ids->data, id))
@@ -346,10 +348,12 @@ static Timing *get_svg_position(gchar *id, GList *ids)
                   if (2==sscanf ((gchar*)ids->data, "Note-%*d-%*d translate(%lf,%lf)%*s%*s", &timing->x, &timing->y))
                     {
                         //g_print ("Found Position %.2f %.2f\n", timing->x, timing->y);
+                        setlocale (LC_ALL, locale);
                         return timing;
                     } else if (2==sscanf ((gchar*)ids->data, "Rest-%*d-%*d translate(%lf,%lf)%*s%*s", &timing->x, &timing->y))
                     {
                        //g_print ("Found Position %.2f %.2f\n", timing->x, timing->y);
+                        setlocale (LC_ALL, locale);
                         return timing;
                     }
 
@@ -357,7 +361,8 @@ static Timing *get_svg_position(gchar *id, GList *ids)
 
 
         }
-    g_warning ("Failed to find a position in events.txt for %s\n", id);
+    setlocale (LC_ALL, locale);
+    g_warning ("Failed to find a position in events.txt for %s, locale reset to %s\n", id, locale);
     return NULL;
 }
 
@@ -388,7 +393,7 @@ static void compute_timings (gchar *base, GList *ids)
         {
             gdouble moment, duration;
             gchar type [10];
-            gint duration_type, col, line, midi;
+            gint  col, line, midi;
             gdouble tempo = 60;
             gdouble timeCoef =  4;
             gdouble latestMoment = 0;
@@ -398,12 +403,14 @@ static void compute_timings (gchar *base, GList *ids)
             gboolean incomingTempo = FALSE;
             while (2 == fscanf (fp, "%lf%10s", &moment, type))
                 {
-                // g_print ("moment %.2f %s latestMoment %.2f\n", moment, type, latestMoment);
+               //g_print ("moment %.2f %s latestMoment %.2f\n", moment, type, latestMoment);
+                moment /= 1000; //now events.txt stores ms to avoid decimal point
                   if (!strcmp (type, "tempo"))
                         {
                             if (1 == fscanf (fp, "%lf", &nextTempo))
                                 {
-                                nextTempoMoment = moment;//g_print ("Next %s %.2f\n", type, nextTempo);
+                                nextTempo /= 1000; //now events.txt stores ms to avoid decimal point
+                                nextTempoMoment = moment;//g_print ("Next tempo %s %.2f\n", type, nextTempo);
                                 incomingTempo = TRUE;
                                 } else g_warning ("Malformed events file");
                         }
@@ -413,7 +420,8 @@ static void compute_timings (gchar *base, GList *ids)
                             {
                             if (4 == fscanf (fp, "%*s%lf%*s%d%d%d", &duration, &col, &line, &midi))
                                     {
-                                       // g_print ("moment ... %.2f %s %d %.2f %d %d %d\n", moment, type, duration_type, duration, col, line, midi);
+                                       //g_print ("moment ... %.2f %s %.2f %d %d %d\n", moment, type, duration, col, line, midi);
+                                       duration /= 1000; //now events.txt stores ms to avoid decimal point
                                        if (incomingTempo)
                                         {
                                             if (moment > nextTempoMoment)
@@ -437,7 +445,7 @@ static void compute_timings (gchar *base, GList *ids)
                                                     timing->col = col;
                                                     timing->time = adjustedElapsedTime;
                                                     timing->duration = duration;
-                                                    add_note (timing);//g_print ("AdjustedElapsed time %.2f note %d\n", adjustedElapsedTime, midi);
+                                                    add_note (timing);//g_print ("AdjustedElapsed time %.2f note %d line %d column %d\n", adjustedElapsedTime, midi, line, col);
                                                     }
                                     }
                                     else
@@ -448,7 +456,8 @@ static void compute_timings (gchar *base, GList *ids)
                             {
                                 if (3 == fscanf (fp, "%*s%lf%*s%d%d",  &duration, &col, &line))
                                     {
-                                       // g_print ("moment ... %.2f %s %d %.2f %d %d %d\n", moment, type, duration_type, duration, col, line, midi);
+                                       //g_print ("moment ... %.2f %s %.2f %d %d %d\n", moment, type, duration, col, line, midi);
+                                       duration /= 1000; //now events.txt stores ms to avoid decimal point
                                        if (incomingTempo)
                                         {
                                             if (moment > nextTempoMoment)
@@ -481,8 +490,13 @@ static void compute_timings (gchar *base, GList *ids)
                             latestMoment = moment;
                         }// not tempo
                     } //while events
+                 //g_print ("Finished collecting timings");
                 fclose (fp);
             } //if events file
+    else
+        {
+          g_critical ("Unable to open file %s Playback View will not work", events);  
+        }
 
     g_free (events);
 }
@@ -574,7 +588,7 @@ set_playback_view (void)
   GFile *file;
   gchar *filename = g_strdup (Denemo.printstatus->printname_svg[Denemo.printstatus->cycle]);
   gboolean multipage = FALSE;
-  //g_print("Output to %s num_pages is %d\n", filename, num_pages);
+  //g_print("Output to %s num_pages starts at %d\n", filename, num_pages);
   if (Denemo.printstatus->invalid)
     g_warning ("We got print status invalid %d\nTypeset may not be good.", Denemo.printstatus->invalid);
   if (!(g_file_test (filename, G_FILE_TEST_EXISTS)))
@@ -597,7 +611,7 @@ set_playback_view (void)
                         return FALSE;
                         }
                     gchar *scheme = g_strdup_printf ("%s%s%s%d%s", "(d-PlaybackView \"(list ", PartOnly?"#t":"#f", " \\\"20\\\" \\\"" , 100 * num_pages, "\\\")\")");
-                    g_print ("Scheme created: %s for %d pages\n", scheme, num_pages);
+                    //g_print ("Scheme created: %s for %d pages\n", scheme, num_pages);
                     call_out_to_guile (scheme);
                     g_free (scheme);
                     return FALSE;
@@ -616,7 +630,7 @@ set_playback_view (void)
 
     compute_timings (g_path_get_dirname(filename), create_positions (filename));
 
-#if 1 //def G_OS_WIN32
+#ifdef G_OS_WIN32
     GError *err = NULL;
     err = NULL;
     //if (Denemo.prefs.dynamic_compression == 88)
@@ -649,6 +663,10 @@ set_playback_view (void)
           show_playback_view ();
         }
     }
+    else
+    {
+       g_critical ("Filename %s was not created - Playback View will not work"); 
+    }
     g_free (filename);
   num_pages = 0;
   return TRUE;
@@ -852,7 +870,7 @@ static void button_press (GtkWidget *event_box, GdkEventButton *event)
 
     if (get_wysiwyg_info()->stage != TypesetForPlaybackView)
        {
-            warningdialog (_("Use the Print View or re-typeset"));
+            warningdialog (_("Use the Print View or re-typeset with All Parts or Current Part buttons"));
             return;
        }
 
@@ -899,7 +917,10 @@ static void button_press (GtkWidget *event_box, GdkEventButton *event)
                             if (found)
                                 call_out_to_guile ("(d-PlayMidiNote 72 255 9 100)");
                         }
-                    //g_print ("Set Playback Start %d column %d\n", timing->line, timing->col);
+                    //if (!found)
+                        //g_print ("Line %d column %d NOT FOUND for (x, y) = (%d, %d) \n", timing->line, timing->col, x, y);
+                    //else
+                        //g_print ("\nFound!!! Line %d column %d for (x, y) = (%d, %d) \n", timing->line, timing->col, x, y);
                     return;
 
                 }
@@ -1016,7 +1037,7 @@ static void list_scroll_points (void) //debug only
    for (g=Denemo.project->movement->scroll_points;g;g=g->next)
         {gdouble adj, tm;
          decode (g->data, &adj, &tm);
-         g_print ("Scroll Point: %0.2f at time %0.2f\n", adj, tm);
+         //g_print ("Scroll Point: %0.2f at time %0.2f\n", adj, tm);
      }
 
 }
@@ -1075,7 +1096,7 @@ static void button_release (GtkWidget *event_box, GdkEventButton *event)
         {
             static gboolean once = TRUE;
             exportmidi (NULL, Denemo.project->movement);
-            g_print ("Now d-changecount %d, d-smfsync %d\n", Denemo.project->movement->changecount, Denemo.project->movement->smfsync);
+            //g_print ("Now d-changecount %d, d-smfsync %d\n", Denemo.project->movement->changecount, Denemo.project->movement->smfsync);
             if(once)
                 infodialog (_("Switching to simple MIDI - re-typeset for full MIDI."));
            once = FALSE;
@@ -1099,7 +1120,7 @@ static void button_release (GtkWidget *event_box, GdkEventButton *event)
                         {
                              if ( (timing->line > Locationy) || ((timing->line==Locationy)&&(timing->col>=Locationx)))
                                 {
-                                    gboolean found = goto_lilypond_position (timing->line, timing->col);g_print ("y %d Lefty %d\n", y, LeftButtonY);
+                                    gboolean found = goto_lilypond_position (timing->line, timing->col);//g_print ("y %d Lefty %d\n", y, LeftButtonY);
 
                                     call_out_to_guile ("(if (not (d-NextChord)) (d-MoveCursorRight))(DenemoSetPlaybackEnd)");
                                         //g_print ("Set playback end to %d column %d\n", timing->line, timing->col);
@@ -1123,7 +1144,7 @@ static void button_release (GtkWidget *event_box, GdkEventButton *event)
 static gint
 hide_playback_on_delete (void)
 {
-  activate_action ("/MainMenu/ViewMenu/" TogglePlaybackView_STRING);
+  set_toggle (TogglePlaybackView_STRING, FALSE);
   return TRUE;
 }
 
