@@ -41,6 +41,7 @@ static ClefInfo clef_info[] = {
   {DENEMO_SOPRANO_CLEF, N_("Soprano")},
   {DENEMO_F_8_CLEF, N_("Bass Octava bassa")},
   {DENEMO_FRENCH_CLEF, N_("French")},
+  {DENEMO_BARITONE_CLEF, N_("Baritone")},
 };
 
 const gchar *
@@ -68,7 +69,7 @@ get_clef_from_name (gchar * name)
  * calls clef change with the INSERT argument
  */
 void
-clef_change_insert (GtkAction * action, DenemoScriptParam * param)
+clef_change_insert (DenemoAction * action, DenemoScriptParam * param)
 {
   GET_1PARAM (action, param, clefname);
   DenemoProject *gui = Denemo.project;
@@ -88,7 +89,7 @@ clef_change_insert (GtkAction * action, DenemoScriptParam * param)
  * calls clef change with the CHANGEINITIAL argument
  */
 void
-clef_change_initial (GtkAction * action, DenemoScriptParam * param)
+clef_change_initial (DenemoAction * action, DenemoScriptParam * param)
 {
   GET_1PARAM (action, param, clefname);
   DenemoProject *gui = Denemo.project;
